@@ -61,38 +61,37 @@ __all__ = [
     'LOG',
     'log',
     'ln',
+    'LN',
     #############
     ## HOISTED ##
     #############
-    *[
-        '_change_activation',
-        '_core',
-        '_dynamic_level',
-        '_find_iter',
-        '_log',
-        '_options',
-        'add',
-        'bind',
-        'catch',
-        'complete',
-        'configure',
-        'contextualize',
-        'critical',
-        'debug',
-        'disable',
-        'enable',
-        'error',
-        'exception',
-        'info',
-        'level',
-        'opt',
-        'parse',
-        'patch',
-        'remove',
-        'start',
-        'stop',
-        'success',
-        'trace',
-        'warning',
-    ],
+    '_change_activation',
+    '_core',
+    '_dynamic_level',
+    '_find_iter',
+    '_log',
+    '_options',
+    'add',
+    'bind',
+    'catch',
+    'complete',
+    'configure',
+    'contextualize',
+    'critical',
+    'debug',
+    'disable',
+    'enable',
+    'error',
+    'exception',
+    'info',
+    'level',
+    'opt',
+    'parse',
+    'patch',
+    'remove',
+    'start',
+    'stop',
+    'success',
+    'trace',
+    'warning',
 ]
